@@ -1,7 +1,7 @@
 package Data::Dmp;
 
 our $DATE = '2015-01-02'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -76,7 +76,7 @@ sub _dump {
     if ($ref eq 'Regexp' || $ref eq 'REGEXP') {
         require re;
         my ($pat, $mod) = re::regexp_pattern($val);
-        $pat =~ s|(?<!\\)(\\\\)*/|$1\\/|g; # escape non-escaped slashes
+        $pat =~ s|(?<!\\)((?:\\\\)*)/|$1\\/|g; # escape non-escaped slashes
         return "qr/$pat/$mod";
     }
 
@@ -161,7 +161,7 @@ Data::Dmp - Dump Perl data structures
 
 =head1 VERSION
 
-This document describes version 0.06 of Data::Dmp (from Perl distribution Data-Dmp), released on 2015-01-02.
+This document describes version 0.07 of Data::Dmp (from Perl distribution Data-Dmp), released on 2015-01-02.
 
 =head1 SYNOPSIS
 
